@@ -41,17 +41,3 @@ def get_redis(settings):
             params[dest] = val
 
     return redis.StrictRedis(**params)
-
-
-def create_topic_client(topic, bootstrap_servers, partitions,
-                        replication_factor):
-    a = AdminClient({'bootstrap.servers': bootstrap_servers})
-
-    new_topics = [NewTopic(topic, num_partitions=partitions, replication_factor=replication_factor)]
-    fs = a.create_topics(new_topics)
-
-    for topic, f in fs.items():
-        try:
-            f.result()  # The result itself is None
-        except Exception as e:
-            print("Failed to create topic {}: {}".format(topic, e))
