@@ -20,10 +20,8 @@ class Kafka_Scrapy_Mixin(object):
         self.kafka_topic = settings.get(
             'KAFKA_START_URLS_KEY', defaults.START_URLS_TOPIC,
         )
-        if settings.get('KAFKA_START_URLS_KEY'):
-            pass
-        else:
-            self.kafka_topic = settings.get('START_TOPIC', self.kafka_topic.format(crawler.settings.get('BOT_NAME')))
+
+        self.kafka_topic = settings.get('START_TOPIC', self.kafka_topic.format(crawler.settings.get('BOT_NAME')))
         self.consumer_ = connection.create_start_request_consumer(name=settings.get('KAFKA_START_GROUP', self.name),
                                                                   bootstrap_servers=settings.get('KAFKA_DEFAULTS_HOST',
                                                                   defaults.KAFKA_DEFAULTS_HOST))
